@@ -3,27 +3,12 @@ package Devel::hdb::App::Base;
 use strict;
 use warnings;
 
-our $VERSION = '0.25';
-
 sub add_route {
     my($class, $method, $path, $cb) = @_;
     my $app = Devel::hdb::App->get();
     $app->router->$method($path, sub { $class->$cb($app, @_) });
 }
 
-sub _read_request_body {
-    my($class, $env) = @_;
-
-    my $buff = '';
-    my $fh = $env->{'psgi.input'};
-    while ($fh->read($buff, 4096, length($buff))) {
-        1;
-    }
-
-    return $buff;
-}
-
-
 1;
 
 =pod
@@ -54,5 +39,5 @@ Anthony Brummett <brummett@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright 2018, Anthony Brummett.  This module is free software. It may
+Copyright 2013, Anthony Brummett.  This module is free software. It may
 be used, redistributed and/or modified under the same terms as Perl itself.
